Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AcceptanceTest ¶
AcceptanceTest is the acceptance test that all implementations of EventStore should pass. It should manually be called from a test case in each implementation:
func TestEventStore(t *testing.T) {
store := NewEventStore()
eventstore.AcceptanceTest(t, store, context.Background())
}
func MaintenanceAcceptanceTest ¶
func MaintenanceAcceptanceTest(t *testing.T, store eh.EventStore, storeMaintenance eh.EventStoreMaintenance, ctx context.Context)
MaintenanceAcceptanceTest is the acceptance test that all implementations of EventStoreMaintenance should pass. It should manually be called from a test case in each implementation:
func TestEventStore(t *testing.T) {
store := NewEventStore()
eventstore.AcceptanceTest(t, store, context.Background())
}
Types ¶
This section is empty.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.